@@ -1,5 +1,66 @@
 import xmllib
 import string
+import re
+
+def remove_duplicate_blanks(text):
+    result=text
+
+    result=string.replace(result,"\t"," ")
+    result=string.replace(result,"\n"," ")
+
+    if (result!=""):
+        temp=""
+        while temp!=result:
+            temp=result
+            result=string.replace(result,"  "," ")
+
+    return result
+
+def format_text(text,left_col,right_col):
+    temp=remove_duplicate_blanks(text)
+
+    result=""
+    p=0
+    l=len(temp)
+    while p<l:
+        cur_line=temp[p:p+right_col-left_col]
+        dp=len(cur_line)
+        if dp==right_col-left_col:
+            i=dp-1
+            while i>0:
+                if cur_line[i]==' ':
+                    break
+                i=i-1
+            if i>0:
+                cur_line=cur_line[0:i]
+                dp=i+1
+                if 0==1: #the following code justifies the text, it is disabled
+                    j=i-1
+                    while len(cur_line)<right_col-left_col-1:
+                        if cur_line[j]==' ':
+                            while j>0 and cur_line[j-1]==' ':
+                                j=j-1
+                                cur_line=cur_line[:j]+' '+cur_line[j:]
+                                j=j-1
+                            if j<0:
+                                j=len(cur_line)-1
+                    
+        result=result+" "*left_col+cur_line+"\n"
+        p=p+dp
+    return result
+
+def format_html(text):
+    result=text
+
+    result=string.replace(result,"<","&lt;")
+
+    email=re.compile('"([\w\-\.]+@[\w\-\.]+)"')
+    result=email.sub(r'<A HREF="mailto:\1">\1</A>',result);
+
+    url=re.compile('"http://([\w\-\./]+)"', re.I)
+    result=url.sub(r'<A HREF="http://\1">\1</A>',result);
+    
+    return result
 
 class XMLToX(xmllib.XMLParser):
     def __init__(self):
@@ -128,7 +189,7 @@ class XMLToHTML(XMLToX):
         self.write("</PRE>\n")
     def translate(self,data,tag):
         result=data
-        result=string.replace(result,"<","&lt;")
+        result=format_html(result)
         return result
 
 class XMLToPHP3(XMLToX):
@@ -176,7 +237,7 @@ class XMLToPHP3(XMLToX):
         self.write("</PRE>\n")
     def translate(self,data,tag):
         result=data
-        result=string.replace(result,"<","&lt;")
+        result=format_html(result)
         return result
 
 class XMLToTeX(XMLToX):
@@ -225,7 +286,7 @@ class XMLToTeX(XMLToX):
             result=string.replace(result,"}","\\}")
             result=string.replace(result,"<","$<$")
             result=string.replace(result,">","$>$")
-        result=string.replace(result,"~","$\\tilde{}$")
+            result=string.replace(result,"~","$\\tilde{}$")
         return result
 
 class XMLToMan(XMLToX):
@@ -267,47 +328,10 @@ class XMLToMan(XMLToX):
         result=string.replace(result,"-","\-")
         if (tag=="CODE"):
             result=string.replace(result,"\n","\n.br\n")
+        else:
+            result=remove_duplicate_blanks(result)
         return result
 
-def format_text(text,left_col,right_col):
-    temp=text
-    temp=string.replace(temp,"\t"," ")
-    temp=string.replace(temp,"\n"," ")
-    if (temp!=""):
-        temp2=""
-        while temp2!=temp:
-            temp2=temp
-            temp=string.replace(temp,"  "," ")
-    result=""
-    p=0
-    l=len(temp)
-    while p<l:
-        cur_line=temp[p:p+right_col-left_col]
-        dp=len(cur_line)
-        if dp==right_col-left_col:
-            i=dp-1
-            while i>0:
-                if cur_line[i]==' ':
-                    break
-                i=i-1
-            if i>0:
-                cur_line=cur_line[0:i]
-                dp=i+1
-                if 0==1: #the following code justifies the text, it is disabled
-                    j=i-1
-                    while len(cur_line)<right_col-left_col-1:
-                        if cur_line[j]==' ':
-                            while j>0 and cur_line[j-1]==' ':
-                                j=j-1
-                                cur_line=cur_line[:j]+' '+cur_line[j:]
-                                j=j-1
-                            if j<0:
-                                j=len(cur_line)-1
-                    
-        result=result+" "*left_col+cur_line+"\n"
-        p=p+dp
-    return result
-
 class XMLToTxt(XMLToX):
     def __init__(self,header):
         XMLToX.__init__(self)
