@@ -8,7 +8,8 @@ echo "Converting files to Unix format..."
 find . -type f "(" \
    -name "*.cpp" -o -name "*.h" -o \
    -name "*.lua" -o -name "*.theme" -o \
-   -name "*.xml" -o -name "*.tex.in" -o -name "*.html.in" -o \
+   -name "*.xml" -o \
+   -name "*.tex.in" -o -name "*.html.in" -o -name "*.man.in" -o \
    -name "*.py" -o \
    -name "makefile.in" \
    ")" \
