@@ -193,18 +193,12 @@ function color_match_pattern(match_count,min_size)
     nb_found=0
     found=0
 
-    if (nb_found<min_size) then
-        nb_found=color_match_vertical(min_size)
-    end
-    if (nb_found<min_size) then
-        nb_found=color_match_horizontal(min_size)
-    end
-    if (nb_found<min_size) then
-        nb_found=color_match_diagonal1(min_size)
-    end
-    if (nb_found<min_size) then
-        nb_found=color_match_diagonal2(min_size)
-    end
+    color_match_vertical(min_size)
+    color_match_horizontal(min_size)
+    color_match_diagonal1(min_size)
+    color_match_diagonal2(min_size)
+
+    nb_found=utils_get_exploding_squares()
 
     if nb_found>=min_size then
         u61_add_score((match_count+1)*10
