@@ -7,13 +7,13 @@ function fiftytwo_do_curse(sent)
     if sent==0 then
         u61_send_curse(ID_CURSE_FIFTYTWO)
     else
-        u61_register_curse(ID_CURSE_FIFTYTWO,60)
+        u61_register_curse(ID_CURSE_FIFTYTWO,6000,0)
     end
 end
 
 function fiftytwo_do_shape(num)
     if u61_get_curse_age(ID_CURSE_FIFTYTWO)>=0 then
-        u61_reset_block()
+        u61_clear_block()
         if mod(num,2)==0 then
             tetramino_s1()
         else
