@@ -9,7 +9,7 @@ function wind_do_curse(sent)
     if sent==0 then
         u61_send_curse(ID_CURSE_WIND)
     else
-        u61_register_curse(ID_CURSE_WIND,300)
+        u61_register_curse(ID_CURSE_WIND,30000,0)
         wind_reset_globals()
     end
 end
@@ -33,3 +33,5 @@ function wind_reset_globals()
 end
 
 
+
+
