@@ -57,6 +57,8 @@ function user_do_shape(num)
     end
 
     fiftytwo_do_shape(num)
+
+    onlybars_do_shape(num)
 end
 
 
@@ -123,30 +125,32 @@ function user_new_curse(num)
 
     if num<10 then
         num=ID_CURSE_ANTIDOTE
-    elseif num<20 then
+    elseif num<25 then
         num=ID_CURSE_HOLEDLINE
     elseif num<30 then
         num=ID_CURSE_GOOFY
-    elseif num<40 then
+    elseif num<35 then
         num=ID_CURSE_CLEAR
-    elseif num<45 then 
+    elseif num<40 then 
         num=ID_CURSE_DROP
-    elseif num<50 then 
+    elseif num<45 then 
         num=ID_CURSE_NOHANDS
-    elseif num<55 then 
+    elseif num<50 then 
         num=ID_CURSE_METAMORPHOSE
-    elseif num<60 then 
+    elseif num<55 then 
         num=ID_CURSE_SIDES
-    elseif num<65 then 
+    elseif num<60 then 
         num=ID_CURSE_STAIRS
-    elseif num<70 then 
+    elseif num<65 then 
         num=ID_CURSE_BOOST
-    elseif num<75 then 
+    elseif num<70 then 
         num=ID_CURSE_SHUFFLE
-    elseif num<80 then 
+    elseif num<75 then 
         num=ID_CURSE_WIND
-    elseif num<84 then 
+    elseif num<80 then 
         num=ID_CURSE_FIFTYTWO
+    elseif num<84 then 
+        num=ID_CURSE_ONLYBARS
     elseif num<88 then 
         num=ID_CURSE_BIGX
     elseif num<92 then 
@@ -181,6 +185,8 @@ function user_do_curse(num,sent)
         wind_do_curse(sent)
     elseif (num==ID_CURSE_FIFTYTWO) then
         fiftytwo_do_curse(sent)
+    elseif (num==ID_CURSE_ONLYBARS) then
+        onlybars_do_curse()
     elseif (num==ID_CURSE_BIGX) then
         bigx_do_curse(sent)
     elseif (num==ID_CURSE_BOOST) then
@@ -221,6 +227,8 @@ function user_get_curse_name(num)
         name="wind"
     elseif (num==ID_CURSE_FIFTYTWO) then
         name="52"
+    elseif (num==ID_CURSE_ONLYBARS) then
+        name="bars"
     elseif (num==ID_CURSE_BIGX) then
         name="X"
     elseif (num==ID_CURSE_BOOST) then
