@@ -21,6 +21,8 @@
  ---------------------------------------------------------------------------*/
 
 #include "compiler.h"
+#include <ClanLib/display.h>
+#include <ClanLib/sound.h>
 #include <ClanLib/mikmod.h>
 
 /*---------------------------------------------------------------------------
@@ -49,6 +51,8 @@ char *U61_Compiler::get_title()
 int U61_Compiler::main(int argc, char** argv)
 {
   CL_SetupCore::init();
+  CL_SetupDisplay::init();
+  CL_SetupSound::init();
   CL_SetupMikMod::init();
 
   if (argc>=3)
@@ -64,6 +68,8 @@ int U61_Compiler::main(int argc, char** argv)
     }
 
   CL_SetupMikMod::deinit();
+  CL_SetupSound::deinit();
+  CL_SetupDisplay::deinit();
   CL_SetupCore::deinit();
 
   return 0;
